/* Speex Xmms plugin
 * (c) Jens Burkal, license: GPL
 * 
 * config.c: Configuration setup file
 *
 */


static void spx_config (void);
static void spx_config_save (GtkButton *);
static void spx_config_save_enhancer (GtkCheckButton *);
static void spx_config_cleanup (void);
static void spx_config_load (void);

/* Internal structure used to store configuration settings */
typedef struct
{
	gboolean enhancer;
} Speex_Config_State;


Speex_Config_State *speex_cs = NULL;




static void spx_config (void) {

	static GtkWidget *window, *enh_frame, *enh_check, *okbutton, *cancelbutton;

	if (speex_cs == NULL) {
		speex_cs = malloc(sizeof(Speex_Config_State));
		memset(speex_cs, 0, sizeof(Speex_Config_State));
	}

	window = gtk_dialog_new();
	gtk_window_set_title(GTK_WINDOW(window), g_strdup("Speex configuration"));
	gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, TRUE);

	enh_frame = gtk_frame_new(g_strdup("Enhancer:"));	
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(window)->vbox), GTK_WIDGET(enh_frame));


	enh_check = gtk_check_button_new_with_label(g_strdup("Enable enhancer (experimental)"));
	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(enh_check), speex_cfg->use_enhancer);
	gtk_signal_connect(GTK_OBJECT(enh_check), "toggled", GTK_SIGNAL_FUNC(spx_config_save_enhancer), NULL);
	gtk_container_add(GTK_CONTAINER(enh_frame), GTK_WIDGET(enh_check));
	
	
	
	okbutton = gtk_button_new_with_label(g_strdup("Ok"));
	gtk_signal_connect(GTK_OBJECT(okbutton), "clicked", GTK_SIGNAL_FUNC(spx_config_save), NULL);
	gtk_signal_connect_object(GTK_OBJECT(okbutton), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
	

	
	cancelbutton = gtk_button_new_with_label(g_strdup("Cancel"));
	gtk_signal_connect(GTK_OBJECT(cancelbutton), "clicked", GTK_SIGNAL_FUNC(spx_config_cleanup), NULL);
	gtk_signal_connect_object(GTK_OBJECT(cancelbutton), "clicked", GTK_SIGNAL_FUNC(gtk_widget_destroy), GTK_OBJECT(window));
	

	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(window)->action_area), okbutton);
	gtk_container_add(GTK_CONTAINER(GTK_DIALOG(window)->action_area), cancelbutton);

	gtk_widget_show_all(window);

	return;
}



static void spx_config_save_enhancer (GtkCheckButton *enhancer) {

	speex_cs->enhancer = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(enhancer));

	return;
}


static void spx_config_save (GtkButton *button) {

	ConfigFile *config;

	config = xmms_cfg_open_default_file();

	if (config) {
	
		xmms_cfg_write_boolean(config, g_strdup("speex"), g_strdup("use_enhancer"), speex_cs->enhancer);
		speex_cfg->use_enhancer = speex_cs->enhancer; //Apply the settings right away

		
		if (!(xmms_cfg_write_default_file(config)))
			fprintf(stderr, SELF ": Error writing default configuration file.\n");
	}
	else
		fprintf(stderr, SELF ": Error reading default configuration file.\n");


	spx_config_cleanup();
	
	return;
}

static void spx_config_cleanup (void) {

	// Since the window have been closed, there's no need for speex_cs
	if (speex_cs)
		free(speex_cs);

	return;
	
}

static void spx_config_load (void) {

	ConfigFile *config;

	config = xmms_cfg_open_default_file();

	if (speex_cfg == NULL) {
		speex_cfg = malloc(sizeof(Speex_Configuration));
		memset(speex_cfg, 0, sizeof(Speex_Configuration));
	}
	
	if (config) {

		xmms_cfg_read_boolean(config, g_strdup("speex"), g_strdup("use_enhancer"), &speex_cfg->use_enhancer);

	}
	else
		fprintf(stderr, SELF ": Error reading default configuration file.\n");

}


